@@ -1,14 +1,38 @@
+#include <numeric>      // std::iota
+
 #include <RcppArmadillo.h>
 #include <vector>
 #include <limits>
 #include <algorithm>
-#include <numeric>      // std::iota
+#define NDEBUG 1
 
 // [[Rcpp::depends(RcppArmadillo)]]
+// [[Rcpp::plugins(cpp11)]]
 
 using namespace Rcpp;
 using namespace arma;
 
+// omp_set_num_threads(4);
+
+
+//find max of a list 
+int ListMax(List x){
+	int n1 = x.size();
+		int max1=0;
+		int n2 = 0;
+		for(int i =0 ;i<n1;++i){
+			arma::uvec s4=as<arma::uvec>(x[i]);
+			n2 = max(s4);
+			if(n2>max1){
+				max1=n2;
+			}
+						
+		}
+	
+		return(max1);
+}
+
+
 // Soft thresholding
 double ST1a(double z,double gam){
 
@@ -105,8 +129,8 @@ mat FistaLV(const mat& Y, const mat& Z, mat& B, const double gam, const double e
       colvec BOLDOLD=BOLD;
 	  double thresh=10*eps;
       j=1;
-
-      while(thresh>eps)
+	  double maxiters=1000;
+      while((thresh>eps) & (j<maxiters))
 		  {
 
 			  colvec v=BOLD+((j-2)/(j+1))*(BOLD-BOLDOLD);
@@ -116,9 +140,9 @@ mat FistaLV(const mat& Y, const mat& Z, mat& B, const double gam, const double e
 			  BOLDOLD=BOLD;
 			  BOLD=B1;
 			  j+=1;
-			  if(j>10000){
-				  break;
-			  }
+			  // if(j>10000){
+			  // 	  break;
+			  // }
 
 
 		  }
@@ -586,8 +610,14 @@ colvec ThreshUpdateOO(const mat& ZZ, double lam,const mat& Y,double eps, List gr
 	  colvec BPrev=B;
 	  List active(n1);
 	  List betaActive2(3);
- 
-	  if(max(groups)==0)
+	  int count=0;
+	  for(int i=0; i<n1; ++i)
+		  {
+			  NumericVector g1=groups[i];
+			  count+=max(g1);
+
+		  }
+	  if(count==0)
 		  {
 
 			  B.zeros(kp);
